==> react-native-mock-render-0.0.9.tgz: package/src/components/StatusBar.js <==
/**
 * https://github.com/facebook/react-native/blob/master/Libraries/Components/StatusBar/StatusBar.js
 */
import React from 'react';
import ColorPropType from '../propTypes/ColorPropType';


let _backgroundColor = '';
let _barStyle = {};
let _hidden = false;
let _networkActivityIndicatorVisible = false;
let _translucent = false;

const StatusBar = React.createClass({
  propTypes: {
    animated: React.PropTypes.bool,
    barStyle: React.PropTypes.oneOf(['default', 'light-content']),
    backgroundColor: ColorPropType,
    hidden: React.PropTypes.bool,
    networkActivityIndicatorVisible: React.PropTypes.bool,
    showHideTransition: React.PropTypes.oneOf(['fade', 'slide']),
    translucent: React.PropTypes.bool,
    children: React.PropTypes.node
  },

  statics: {
    setBackgroundColor(backgroundColor, animated) {
      _backgroundColor = backgroundColor;
    },

    setBarStyle(barStyle, animated) {
      _barStyle = barStyle;
    },

    setHidden(hidden, animated) {
      _hidden = hidden;
    },

    setNetworkActivityIndicatorVisible(visible) {
      _networkActivityIndicatorVisible = visible;
    },

    setTranslucent(translucent) {
      _translucent = translucent;
    },

    __getBackgroundColor() {
      return _backgroundColor;
    },

    __getBarStyle() {
      return _barStyle;
    },

    __getHidden() {
      return _hidden;
    },

    __getNetworkActivityIndicatorVisible() {
      return _networkActivityIndicatorVisible;
    },

    __getTranslucent() {
      return _translucent;
    }
  },

  render() {
    return React.createElement('react-native-mock', null, this.props.children);
  }
});

module.exports = StatusBar;

==> react-native-mock-render-0.0.20.tgz: package/src/components/StatusBar.js <==
/**
 * https://github.com/facebook/react-native/blob/master/Libraries/Components/StatusBar/StatusBar.js
 */
import React from 'react';
import PropTypes from 'prop-types';
import createReactClass from 'create-react-class';
import ColorPropType from '../propTypes/ColorPropType';


let _backgroundColor = '';
let _barStyle = {};
let _hidden = false;
let _networkActivityIndicatorVisible = false;
let _translucent = false;

const StatusBar = createReactClass({
  propTypes: {
    animated: PropTypes.bool,
    barStyle: PropTypes.oneOf(['default', 'light-content']),
    backgroundColor: ColorPropType,
    hidden: PropTypes.bool,
    networkActivityIndicatorVisible: PropTypes.bool,
    showHideTransition: PropTypes.oneOf(['fade', 'slide']),
    translucent: PropTypes.bool,
    children: PropTypes.node
  },

  statics: {
    setBackgroundColor(backgroundColor, animated) {
      _backgroundColor = backgroundColor;
    },

    setBarStyle(barStyle, animated) {
      _barStyle = barStyle;
    },

    setHidden(hidden, animated) {
      _hidden = hidden;
    },

    setNetworkActivityIndicatorVisible(visible) {
      _networkActivityIndicatorVisible = visible;
    },

    setTranslucent(translucent) {
      _translucent = translucent;
    },

    __getBackgroundColor() {
      return _backgroundColor;
    },

    __getBarStyle() {
      return _barStyle;
    },

    __getHidden() {
      return _hidden;
    },

    __getNetworkActivityIndicatorVisible() {
      return _networkActivityIndicatorVisible;
    },

    __getTranslucent() {
      return _translucent;
    }
  },

  render() {
    return React.createElement('react-native-mock', null, this.props.children);
  }
});

module.exports = StatusBar;
